@@ -1,5 +1,7 @@
 # flake8: noqa
+from .continuous import Continuous
 from .multimodal import Multimodal
 from .sawtooth import Sawtooth
 from .step_multimodal import StepMultimodal
+from .step_trap import StepTrap
 from .trap import Trap
