@@ -1,36 +1,35 @@
 import math
-from typing import List
+from typing import Dict, List
 
 import numpy as np
-from lazy import lazy
 from evobench.continuous.continuous import Continuous
+from evobench.separable import Separable
+from lazy import lazy
 
 
-class StepMultimodal(Continuous):
+class StepMultimodal(Separable, Continuous):
 
     def __init__(
         self,
         blocks: List[int],
         step_size: int,
+        blocks_scaling: List[int] = None,
         overlap_size: int = 0,
-        shuffle: bool = False,
+        use_shuffle: bool = False,
         multiprocessing: bool = False,
         verbose: int = 0
     ):
         super(StepMultimodal, self).__init__(
             blocks,
+            blocks_scaling,
             overlap_size,
-            shuffle,
+            use_shuffle,
             multiprocessing,
             verbose
         )
 
         self.STEP_SIZE = step_size
 
-    @lazy
-    def global_opt(self) -> float:
-        return float(len(self.BLOCKS))
-
     def evaluate_block(self, block: np.ndarray, block_index: int) -> float:
         s = np.sum(block)
         fitness = abs(math.sin(s))
@@ -40,3 +39,13 @@ class StepMultimodal(Continuous):
         fitness *= self.STEP_SIZE
 
         return fitness
+
+    @lazy
+    def as_dict(self) -> Dict:
+        as_dict = {}
+        as_dict['step_size'] = self.STEP_SIZE
+
+        separable_as_dict = super().as_dict
+        as_dict = {**separable_as_dict, **as_dict}
+
+        return as_dict
