@@ -1,5 +1,7 @@
 # flake8: noqa
 from .bimodal import Bimodal
+from .bimodal_noised import BimodalNoised
+from .discrete import Discrete
 from .hiff import Hiff
 from .hiff_star import HiffStar
 from .isg.isg import IsingSpinGlass
