@@ -1,6 +1,8 @@
+from typing import List
+
 import numpy as np
-from evobench.model.solution import Solution
 from evobench.benchmark import Benchmark
+from evobench.model.solution import Solution
 from evobench.util import shuffle
 from lazy import lazy
 
@@ -31,18 +33,22 @@ class Discrete(Benchmark):
 
     def fix(self, solution: Solution) -> Solution:
         solution = super(Discrete, self).fix(solution)
-        genome = solution.genome.astype(dtype=np.int)
+        genome = solution.genome.astype(dtype=int)
 
         return Solution(genome)
 
-    def random_solution(self) -> Solution:
-        genome = np.random.uniform(low=0, high=2, size=self.genome_size)
+    def random_solutions(self, population_size: int) -> List[Solution]:
+        genomes = np.random.uniform(
+            low=0,
+            high=2,
+            size=(population_size, self.genome_size)
+        )
 
-        genome *= self.bound_range
-        genome -= self.lower_bound
-        genome = genome.astype(dtype=np.int)
+        genomes *= self.bound_range
+        genomes -= self.lower_bound
+        genomes = genomes.astype(dtype=int)
 
         if self.USE_SHUFFLE:
-            genome = shuffle(genome, self.gene_order)
+            genomes = shuffle(genomes, self.gene_order)
 
-        return Solution(genome)
+        return list(Solution(genome) for genome in genomes)
